import os
import flask
import json
from flask import render_template, request
from flask import jsonify
from werkzeug.utils import secure_filename
from app import app
from main import getColorPrediction, getInsectPrediction, getLeafPrediction, predictFertilizer


@app.route('/', methods=['GET'])
def index():
    # Main page
    return render_template('index.html')


@app.route('/predictInsect', methods=['POST'])
def submit_file():
    if request.method == 'POST':
        if 'file' not in request.files:
            return jsonify({'error': 'No file part'})
        file = request.files['file']
        if file.filename == '':
            return jsonify({'error': 'No file selected for uploading'})
        if file:
            filename = secure_filename(file.filename)
            file.save(os.path.join(app.config['UPLOAD_FOLDER'], filename))
            label, acc = getInsectPrediction(filename)
            response = {
                'label': label,
                'probability': acc
            }
            return jsonify(response)
    else:
        return jsonify({'error': 'Invalid request method'})


@app.route('/predictColor', methods=['POST'])
def submit_file_color():
    if request.method == 'POST':
        if 'file' not in request.files:
            return jsonify({'error': 'No file part'})
        file = request.files['file']
        if file.filename == '':
            return jsonify({'error': 'No file selected for uploading'})
        if file:
            filename = secure_filename(file.filename)
            file.save(os.path.join(app.config['UPLOAD_FOLDER'], filename))
            label, acc = getColorPrediction(filename)
            response = {
                'label': label,
                'probability': acc
            }
            return jsonify(response)
    else:
        return jsonify({'error': 'Invalid request method'})


@app.route('/predictLeaf', methods=['POST'])
def submit_file_leaf():
    if request.method == 'POST':
        if 'file' not in request.files:
            return jsonify({'error': 'No file part'})
        file = request.files['file']
        if file.filename == '':
            return jsonify({'error': 'No file selected for uploading'})
        if file:
            filename = secure_filename(file.filename)
            file.save(os.path.join(app.config['UPLOAD_FOLDER'], filename))
            label, acc = getLeafPrediction(filename)
            response = {
                'label': label,
                'probability': acc
            }
            return jsonify(response)
    else:
        return jsonify({'error': 'Invalid request method'})


@app.route('/predictFertilizer', methods=['POST'])
def submit_yield():
    msg_received = flask.request.get_json()
    rsp = predictFertilizer(msg_received)
    return json.dumps(rsp.__dict__)


if __name__ == '__main__':
    app.run(debug=True, port=4000)
